# -*- coding: utf-8 -*-

"""Top-level package for Barril."""

__author__ = """ESSS"""
__email__ = "foss@esss.co"
